@@ -2,13 +2,12 @@
 
 
 package Device::Hypnocube;
-$Device::Hypnocube::VERSION = '1.900.400';
+$Device::Hypnocube::VERSION = '1.2';
 use 5.010;
 use strict;
 use warnings;
 use Moo;
 use Time::HiRes qw( gettimeofday usleep);
-use WebColors;
 
 # get the crc stuff, this is the function we need
 use Digest::CRC qw( crcccitt );
@@ -40,11 +39,10 @@ use constant HYPNOCUBE_FLIP   => 80;
 use constant HYPNOCUBE_FRAME  => 81;
 use constant HYPNOCUBE_PIXEL  => 81;
 
-use constant X_SIZE        => 4;
-use constant Y_SIZE        => 4;
-use constant Z_SIZE        => 4;
-use constant BUFFER_SIZE   => X_SIZE * Y_SIZE * Z_SIZE;
-use constant DEFAULT_COLOR => 'purple';
+use constant X_SIZE      => 4;
+use constant Y_SIZE      => 4;
+use constant Z_SIZE      => 4;
+use constant BUFFER_SIZE => X_SIZE * Y_SIZE * Z_SIZE;
 
 use constant RATE_LIMIT_MSECS => 3333;    # 1/30 * 1e6
 
@@ -69,10 +67,27 @@ my %errors = (
 );
 
 my %colors = (
+    black       => [ 0,    0,    0 ],
+    lilac       => [ 0xf0, 0,    0xf0 ],
+    orange      => [ 0xf0, 0x20, 0 ],
+    amber       => [ 0xf0, 0x20, 0 ],
+    warmwhite   => [ 0xa0, 0xa0, 0xa0 ],
+    purple      => [ 0x10, 0,    0x10 ],
+    lightpurple => [ 0x40, 0,    0x40 ],
 
-    # colors are generated in BUILDARGS
+    # colors are now generated
+    # darkblue    => [ 0,    0,    0x10 ],
+    # blue        => [ 0,    0,    0xf0 ],
+    # cyan        => [ 0,    0x60, 0x60 ],
+    # darkgreen   => [ 0,    0x10, 0 ],
+    # green       => [ 0,    0xf0, 0 ],
+    # red         => [ 0xf0, 0,    0 ],
+    # darkred     => [ 0x10, 0,    0 ],
+    # white       => [ 0xf0, 0xf0, 0xf0 ],
+    # yellow      => [ 0xf0, 0xf0, 0 ],
+    # magenta     => [ 0xa0, 0,    0xa0 ],
+    pink => [ 0xf0, 0x00, 0x20 ]
 );
-my @color_names;
 
 # ----------------------------------------------------------------------------
 # instance initialisation
@@ -148,20 +163,12 @@ around BUILDARGS => sub {
     # here we can extract and extra args we want to process but do not have
     # object variables for
 
-    # add in the web_colors
-    # we reduce them by 75% as the LEDs are not that accurate
-    foreach my $c ( list_webcolors() ) {
-        my ( $r, $g, $b ) = colorname_to_rgb($c);
-
-        # reduce them as they are too bright
-        $colors{$c} = [ int( $r / 4 ), int( $g / 4 ), int( $b / 4 ) ];
-    }
+    my @prefix = ( "dark", "mid", "", "bright" );
 
     # add extra color names for primaries and close relatives
-    my @prefix = ( "dark", "mid", "", "bright" );
     for ( my $i = 0; $i <= 3; $i++ ) {
-        my $c = ( 64 * ( $i + 1 ) );
-        $c = $c >= 256 ? 255 : $c;
+        my $c = ( 64 * ( $i + 1 ) ) ;
+        $c = $c > 256 ? 255 : $c ;
         my $p = $prefix[$i];
         $colors{ $p . "red" } = [ $c, 0, 0 ];
         $colors{ $p . "green" } = [ 0, $c, 0 ];
@@ -173,18 +180,6 @@ around BUILDARGS => sub {
         $colors{ $p . "white" } = [ $c, $c, $c ];
     }
 
-    # define some colors by hand as we want them more vibrant or they
-    # are not quite right in WebColors
-
-    $colors{lilac}       = [ 0xf0, 0,    0xf0 ];
-    $colors{orange}      = [ 0xf0, 0x20, 0 ];
-    $colors{amber}       = [ 0xf0, 0x20, 0 ];
-    $colors{warmwhite}   = [ 0xa0, 0xa0, 0xa0 ];
-    $colors{lightpurple} = [ 0x40, 0,    0x40 ];
-    $colors{pink}        = [ 0xf0, 0x00, 0x20 ];
-
-    @color_names = keys %colors;
-
     # now build the class properly
     return $class->$orig(@_);
 };
@@ -220,15 +215,15 @@ sub DEMOLISH {
 # some of these are the things being $self->send_data( HYPNOCUBE_ERR, 0)assed to new
 # ----------------------------------------------------------------------------
 
-sub set_error {
-    my $self = shift;
-    my $code = shift;
+# sub set_error {
+#     my $self = shift;
+#     my $code = shift;
 
-    my $errmsg = { code => $code, error => $errors{$code} };
-    $self->_set_error_info($errmsg);
+#     my $errmsg = { code => $code, error => $errors{$code} };
+#     $self->_set_error_info($errmsg);
 
-    $self->_debug("error: $errors{$code}");
-}
+#     $self->_debug("error: $errors{$code}");
+# }
 
 # ----------------------------------------------------------------------------
 
@@ -614,7 +609,7 @@ sub flip {
 
 sub list_colors {
     my $self = shift;
-    return @color_names;
+    return keys %colors;
 }
 
 # ----------------------------------------------------------------------------
@@ -624,32 +619,11 @@ sub get_color {
     my $self = shift;
     my ( $color, $green, $blue, $default ) = @_;
 
-    $color //= $default;
-    $color //= DEFAULT_COLOR;
-
-    if ( $color =~ /^rand(om)?/i ) {
-        my $r = int( rand( scalar(@color_names) ) );
-        ( $color, $green, $blue ) = @{ $colors{ $color_names[$r] } };
-    }
-    # alias for black
-    if ( $color =~ /^(clear|off)$/i ) {
-        ( $color, $green, $blue ) = (0, 0, 0);
-    }
-
-    my $tc = colorname_to_hex( $color) ;
-    $color = "#$tc" if( $tc) ;
-
-    if ( $color =~ /^(?:0[xX]|#)([[:xdigit:]]+)$/ && !defined $green && !defined $blue ) {
+    if ( defined $color && $color =~ /^(?:0[xX]|#)([[:xdigit:]]+)$/ && !defined $green && !defined $blue ) {
         my $c = $1;
         if ( length($c) == 2 ) {
             $color = $green = $blue = hex($c);
         }
-        elsif ( length($c) == 3 ) {
-            $c =~ /([[:xdigit:]])([[:xdigit:]])([[:xdigit:]])/;
-            $color = hex("$1$1");
-            $green = hex("$2$2");
-            $blue  = hex("$3$3");
-        }
         elsif ( length($c) == 6 ) {
             $c =~ /([[:xdigit:]]{2})([[:xdigit:]]{2})([[:xdigit:]]{2})/;
             $color = hex($1);
@@ -662,15 +636,21 @@ sub get_color {
         }
     }
 
-    if ( $color =~ /^\d+/ && !defined $green && !defined $blue ) {
+    if ( defined $color && $color =~ /^\d+/ && !defined $green && !defined $blue ) {
         $green = $blue = $color;
     }
+    elsif ( !defined $color && !defined $green && !defined $blue ) {
+        $self->_debug("no color using default");
+        $color = $default;
+    }
     elsif ( !$colors{$color} && !defined $green && !defined $blue ) {
-        $self->_debug( "unknown color $color, using default: " . DEFAULT_COLOR );
-        $color = DEFAULT_COLOR;
+        $self->_debug("unknown color $color, using white");
+        $color = 'white';
     }
     ( $color, $green, $blue ) = @{ $colors{$color} } if ( $colors{$color} );
 
+    # say "$color, $green, $blue" ;
+
     return ( $color, $green, $blue );
 }
 
@@ -884,7 +864,7 @@ Device::Hypnocube - Control a hypnocube
 
 =head1 VERSION
 
-version 1.900.400
+version 1.2
 
 =head1 SYNOPSIS
 
@@ -895,8 +875,7 @@ version 1.900.400
 
 =head1 DESCRIPTION
 
-Control the 4x4x4 Hypnocube available from usb.brando.com 
-(http://usb.brando.com/4x4x4-multi-color-led-cube_p01963c35d15.html)
+Control the 4x4x4 Hypnocube available from usb.brando.com
 see also http://www.hypnocube.com/
 I consider the front to be the side with the power and serial connectors
 0,0,0 is then at bottom back left
@@ -1044,7 +1023,7 @@ Kevin Mulholland <moodfarm@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Kevin Mulholland.
+This software is copyright (c) 2014 by Kevin Mulholland.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
